import QtQuick 2.5
import QtQuick.Controls 1.4
import QtQuick.Layouts 1.2

Item {
    id: item1
	width: 640
	height: 480

    property alias image1: image1
    property alias mouseArea1: mouseArea1
    property alias tabView1: tabView1
    property alias drawTool: drawTool
    property alias selectTool: selectTool
    property alias copyTool: copyTool
    property alias cutTool: cutTool
    property alias pasteTool: pasteTool

    ScrollView {
        anchors.right: columnLayout1.left
        anchors.rightMargin: 6
        anchors.left: parent.left
        anchors.leftMargin: 8
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 8
        anchors.top: parent.top
        anchors.topMargin: 8
        highlightOnFocus: false
        verticalScrollBarPolicy: 0
        horizontalScrollBarPolicy: 0
        frameVisible: true

        Image {
            id: image1
            fillMode: Image.Pad
            cache: false
            clip: true
            horizontalAlignment: Image.AlignLeft
            verticalAlignment: Image.AlignTop
            source: "image://myimageprovider/0"

            MouseArea {
                id: mouseArea1
                anchors.fill: parent
                hoverEnabled: true
                acceptedButtons: Qt.LeftButton | Qt.RightButton
            }
        }
    }

    TabView {
        id: tabView1
        opacity: 1
        frameVisible: true
        tabsVisible: true
        anchors.right: parent.right
        anchors.rightMargin: 8
        anchors.top: parent.top
        anchors.topMargin: 8

        Tab {
            id:mapTab
            title: qsTr("Map")
            source:"/MapTab.qml"
        }

        Tab {
            title: qsTr("Tiles")

            Grid {
                id: grid2
                columns: 2
                spacing: 5

                Item {
                    id: item3
                    width: 1
                    height: 1
                }
            }
        }

        Tab {
            title: qsTr("Walls")
        }

        Tab {
            title: qsTr("Objects")
        }
    }

    Column {
        id: columnLayout1
        spacing: 3
        anchors.top: parent.top
        anchors.topMargin: 8
        anchors.right: tabView1.left
        anchors.rightMargin: 8
        enabled: tabView1.currentIndex != 0

        Button {
            id: drawTool
            width: 38
            height: 38
            checkable: true
            checked: true

            Image
            {
                opacity: (drawTool.enabled ? 1.0 : 0.5)
                source: "gfx/pencil.png"
                anchors.fill: parent
                anchors.margins: 4
            }
        }

        Button {
            id: selectTool
            width: 38
            height: 38
            Image {
                source: "gfx/select.png"
                opacity: (selectTool.enabled ? 1.0 : 0.5)
                anchors.margins: 4
                anchors.fill: parent
            }
            checkable: true
        }

        Button {
            id: copyTool
            width: 38
            height: 38
            Image {
                source: "gfx/copy.png"
                opacity: (selectTool.enabled ? 1.0 : 0.5)
                anchors.margins: 4
                anchors.fill: parent
            }
        }

        Button {
            id: cutTool
            width: 38
            height: 38
            Image {
                source: "gfx/cut.png"
                opacity: (selectTool.enabled ? 1.0 : 0.5)
                anchors.margins: 4
                anchors.fill: parent
            }
        }

        Button {
            id: pasteTool
            width: 38
            height: 38
            Image {
                source: "gfx/paste.png"
                opacity: (selectTool.enabled ? 1.0 : 0.5)
                anchors.margins: 4
                anchors.fill: parent
            }
        }
    }
}

