import QtQuick 2.5
import QtQuick.Controls 1.4
import QtQuick.Dialogs 1.2

ApplicationWindow {
    visible: true
    visibility: "Maximized"
    width: 640
    height: 480
    title: qsTr("Map Editor v0.3")
    property int frame: 1

    FileDialog {
        id: saveDialog
        visible: false
        title: "Please choose a file"
        folder: "file:///maps"
        nameFilters: [ "Map files (*.map)", "All files (*)" ]
        selectExisting: false;
        onAccepted: {
            bridge.save(fileUrl);
            visible=false;
        }

        onRejected: visible=false;
    }

    FileDialog {
        id: loadDialog
        visible: false
        title: "Please choose a file"
        folder: "file:///maps"
        nameFilters: [ "Map files (*.map)", "All files (*)" ]
        selectExisting: true;
        onAccepted: {
            bridge.load(fileUrl);
            visible=false;
        }

        onRejected: visible=false;
    }

    menuBar: MenuBar {
        Menu {
            title: qsTr("File")
            MenuItem {
                text: qsTr("Load")
                onTriggered: loadDialog.visible = true;
            }
            MenuItem {
                text: qsTr("Save")
                onTriggered: saveDialog.visible = true;
            }
            MenuItem {
                text: qsTr("Exit")
                onTriggered: Qt.quit();
            }
        }
    }

    MainForm {
        id: main
        anchors.fill: parent

        function resetTools()
        {
            drawTool.checked = false;
            selectTool.checked = false;
        }

        mouseArea1.onMouseXChanged: bridge.setMouse(mouseArea1.mouseX, mouseArea1.mouseY);
        mouseArea1.onMouseYChanged: bridge.setMouse(mouseArea1.mouseX, mouseArea1.mouseY);
        mouseArea1.onExited: bridge.setMouse(-1, -1);
        mouseArea1.onEntered: bridge.setMouse(mouseArea1.mouseX, mouseArea1.mouseY);
        mouseArea1.onPressed: bridge.setMousePress(mouse.button);
        mouseArea1.onReleased: bridge.setMouseRelease(mouse.button);

        drawTool.onClicked: {
            resetTools();
            drawTool.checked = true;
        }

        selectTool.onClicked: {
            resetTools();
            selectTool.checked = true;
        }

        copyTool.onClicked: {}
        cutTool.onClicked: {}
        pasteTool.onClicked: {}

        tabView1.onCurrentIndexChanged: bridge.setTabIndex(tabView1.currentIndex);

        Connections {
            target: bridge
            onNewFrameAvailable: {
                main.image1.source = "image://myimageprovider/" + frame;
                frame++;
            }
        }
    }
}

