#include <QDebug>
#include "bridge.h"
#include "editor.h"
#include "../common/sources/Map.h"

CBridge     bridge;

//---------------------------------------------------------------------------------------------
CBridge::CBridge(QObject *parent) : QObject(parent)
{
    // default values
    mMapSize = CVec2(15, 10);
    mMousePos = CVec2(-1, -1);
    leftPressed = false;
    rightPressed = false;
    mTabIndex = false;
}

void    CBridge::setMapWidth(qint32 valeur)
{
    mMapSize.x = valeur;
}

void    CBridge::setMapHeight(qint32 valeur)
{
    mMapSize.y = valeur;
}

void    CBridge::setMouse(qint32 x, qint32 y)
{
    mMousePos = CVec2(x, y);

    editor.useTool();
    updateQMLImage();
}

void    CBridge::setMousePress(qint32 button)
{
    if (button == Qt::LeftButton)
        leftPressed = true;
    else if (button == Qt::RightButton)
        rightPressed = true;

    editor.useTool();
    updateQMLImage();
}

void    CBridge::setMouseRelease(qint32 button)
{
    if (button == Qt::LeftButton)
        leftPressed = false;
    else if (button == Qt::RightButton)
        rightPressed = false;

    editor.useTool();
    updateQMLImage();
}

void CBridge::setTabIndex(qint32 index)
{
    mTabIndex = index;
}

void    CBridge::resizeMap()
{
    map.mSize = mMapSize;
    map.resize();
    updateQMLImage();
}

void    CBridge::save(QString fileName)
{
    // [8] to remove "file:///"
    map.save(&fileName.toLocal8Bit().data()[8]);
}

void    CBridge::load(QString fileName)
{
    // [8] to remove "file:///"
    map.load(&fileName.toLocal8Bit().data()[8]);
    updateQMLImage();
}

//---------------------------------------------------------------------------------------------
MyImageProvider::MyImageProvider() : QQuickImageProvider(QQuickImageProvider::Image)
{
}

QImage MyImageProvider::requestImage(const QString &id, QSize *size, const QSize &requestedSize)
{
    QImage image = editor.displayMap(map, bridge.mMousePos, bridge.mTabIndex);

    if (size != NULL)
        *size = QSize(image.width(), image.height());

    return image;
}
